@@ -64,7 +64,7 @@
 #define PAS_ID_PREFIX "pas-id-"
 #define SUMMARY_FLUSH_TIMEOUT 5000
 
-static EBookBackendSyncClass *e_book_backend_file_parent_class;
+G_DEFINE_TYPE (EBookBackendFile, e_book_backend_file, E_TYPE_BOOK_BACKEND_SYNC);
 
 struct _EBookBackendFilePrivate {
 	char     *dirname;
@@ -80,7 +80,7 @@ struct _EBookBackendFilePrivate {
 	void *reserved4;
 };
 
-static GStaticMutex global_env_lock = G_STATIC_MUTEX_INIT;
+G_LOCK_DEFINE_STATIC (global_env);
 static struct {
 	int ref_count;
 	DB_ENV *env;
@@ -1077,7 +1077,7 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 		return db_error_to_status (db_error);
 	}
 
-	g_static_mutex_lock(&global_env_lock);
+	G_LOCK (global_env);
 	if (global_env.ref_count > 0) {
 		env = global_env.env;
 		global_env.ref_count++;
@@ -1085,7 +1085,7 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 		db_error = db_env_create (&env, 0);
 		if (db_error != 0) {
 			g_warning ("db_env_create failed with %s", db_strerror (db_error));
-			g_static_mutex_unlock(&global_env_lock);
+			G_UNLOCK (global_env);
 			g_free (dirname);
 			g_free (filename);
 			return db_error_to_status (db_error);
@@ -1102,7 +1102,7 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 		if (db_error != 0) {
 			env->close(env, 0);
 			g_warning ("db_env_open failed with %s", db_strerror (db_error));
-			g_static_mutex_unlock(&global_env_lock);
+			G_UNLOCK (global_env);
 			g_free (dirname);
 			g_free (filename);
 			return db_error_to_status (db_error);
@@ -1111,7 +1111,7 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 		global_env.env = env;
 		global_env.ref_count = 1;
 	}
-	g_static_mutex_unlock(&global_env_lock);
+	G_UNLOCK (global_env);
 
 	bf->priv->env = env;
 
@@ -1194,9 +1194,11 @@ e_book_backend_file_load_source (EBookBackend           *backend,
 			else {
 #ifdef CREATE_DEFAULT_VCARD
 				EContact *contact = NULL;
-
-				do_create(bf, XIMIAN_VCARD, &contact);
-				/* XXX check errors here */
+				EBookBackendSyncStatus status;
+				
+				status = do_create (bf, XIMIAN_VCARD, &contact);
+				if (status != GNOME_Evolution_Addressbook_Success)
+					g_warning ("Cannot create default contact: %d", status);
 				if (contact)
 					g_object_unref (contact);
 #endif
@@ -1396,13 +1398,13 @@ e_book_backend_file_dispose (GObject *object)
 		bf->priv->file_db = NULL;
 	}
 	
-	g_static_mutex_lock(&global_env_lock);
+	G_LOCK (global_env);
 	global_env.ref_count--;
 	if (global_env.ref_count == 0) {
 		global_env.env->close (global_env.env, 0);
 		global_env.env = NULL;
 	}
-	g_static_mutex_unlock (&global_env_lock);
+	G_UNLOCK (global_env);
 	
 	if (bf->priv->summary) {
 		g_object_unref (bf->priv->summary);
@@ -1479,8 +1481,6 @@ e_book_backend_file_class_init (EBookBackendFileClass *klass)
 	EBookBackendSyncClass *sync_class;
 	EBookBackendClass *backend_class;
 
-	e_book_backend_file_parent_class = g_type_class_peek_parent (klass);
-
 	sync_class = E_BOOK_BACKEND_SYNC_CLASS (klass);
 	backend_class = E_BOOK_BACKEND_CLASS (klass);
 
@@ -1528,30 +1528,3 @@ e_book_backend_file_init (EBookBackendFile *backend)
 
 	backend->priv = priv;
 }
-
-/**
- * e_book_backend_file_get_type:
- */
-GType
-e_book_backend_file_get_type (void)
-{
-	static GType type = 0;
-
-	if (! type) {
-		GTypeInfo info = {
-			sizeof (EBookBackendFileClass),
-			NULL, /* base_class_init */
-			NULL, /* base_class_finalize */
-			(GClassInitFunc)  e_book_backend_file_class_init,
-			NULL, /* class_finalize */
-			NULL, /* class_data */
-			sizeof (EBookBackendFile),
-			0,    /* n_preallocs */
-			(GInstanceInitFunc) e_book_backend_file_init
-		};
-
-		type = g_type_register_static (E_TYPE_BOOK_BACKEND_SYNC, "EBookBackendFile", &info, 0);
-	}
-
-	return type;
-}
