@@ -3,7 +3,7 @@
 #include <config.h>
 
 #include "e-book-query.h"
-#include <libedataserver/e-sexp.h>
+#include "libedataserver/e-sexp.h"
 
 #include <stdarg.h>
 #include <string.h>
@@ -552,7 +552,7 @@ static const struct {
  *
  * Parse @query_string and return a new #EBookQuery representing it.
  *
- * Return value: the new #EBookValue
+ * Return value: the new #EBookQuery.
  **/
 EBookQuery*
 e_book_query_from_string  (const char *query_string)
