@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -337,8 +337,8 @@ cobject_meta_get(CamelObject *obj, const char * name)
 	CamelObjectMeta *meta;
 	char *res = NULL;
 
-	g_return_val_if_fail(CAMEL_IS_OBJECT (obj), 0);
-	g_return_val_if_fail(name != NULL, 0);
+	g_return_val_if_fail(CAMEL_IS_OBJECT (obj), NULL);
+	g_return_val_if_fail(name != NULL, NULL);
 
 	pair = co_metadata_pair(obj, FALSE);
 	if (pair) {
@@ -458,9 +458,13 @@ cobject_state_read(CamelObject *obj, FILE *fp)
 			/* maybe it was just version 0 afterall */
 			return 0;
 		}
+
+		count = MIN(count, CAMEL_ARGV_MAX);
 		
 		/* we batch up the properties and set them in one go */
-		if (!(argv = g_try_malloc ((gulong)(sizeof (*argv) + (count - CAMEL_ARGV_MAX) * sizeof (argv->argv[0])))))
+		argv = g_try_malloc(sizeof(CamelArgV) -
+			((CAMEL_ARGV_MAX - count) * sizeof(CamelArg)));
+		if (argv == NULL)
 			return -1;
 		
 		argv->argc = 0;
@@ -539,9 +543,12 @@ cobject_state_write(CamelObject *obj, FILE *fp)
 	   we also need an argv to store the results - bit messy */
 
 	count = g_slist_length(props);
+	count = MIN(count, CAMEL_ARGV_MAX);
 
-	arggetv = g_malloc0(sizeof(*arggetv) + (count - CAMEL_ARGV_MAX) * sizeof(arggetv->argv[0]));
-	argv = g_malloc0(sizeof(*argv) + (count - CAMEL_ARGV_MAX) * sizeof(argv->argv[0]));
+	arggetv = g_malloc0(sizeof(CamelArgGetV) -
+		((CAMEL_ARGV_MAX - count) * sizeof(CamelArgGet)));
+	argv = g_malloc0(sizeof(CamelArgV) -
+		((CAMEL_ARGV_MAX - count) * sizeof(CamelArg)));
 	l = props;
 	i = 0;
 	while (l) {
@@ -1616,7 +1623,7 @@ void *camel_object_get_ptr(void *vo, CamelException *ex, int tag)
 	g_return_val_if_fail(CAMEL_IS_OBJECT(o), NULL);
 	g_return_val_if_fail((tag & CAMEL_ARG_TYPE) == CAMEL_ARG_OBJ
 			     || (tag & CAMEL_ARG_TYPE) == CAMEL_ARG_STR
-			     || (tag & CAMEL_ARG_TYPE) == CAMEL_ARG_PTR, 0);
+			     || (tag & CAMEL_ARG_TYPE) == CAMEL_ARG_PTR, NULL);
 
 	/* woefully inefficient, *shrug */
 	args.argc = 1;
@@ -1754,8 +1761,8 @@ camel_object_meta_get(void *vo, const char * name)
 {
 	CamelObject *obj = vo;
 
-	g_return_val_if_fail(CAMEL_IS_OBJECT (obj), 0);
-	g_return_val_if_fail(name != NULL, 0);
+	g_return_val_if_fail(CAMEL_IS_OBJECT (obj), NULL);
+	g_return_val_if_fail(name != NULL, NULL);
 
 	return obj->klass->meta_get(obj, name);
 }
