@@ -5,7 +5,7 @@
  * Authors: Michael Zucchi <notzed@ximian.com>
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
+ * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -13,33 +13,34 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * General Public License for more details.
  *
- * You should have received a copy of the GNU General Public
+ * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include <ctype.h>
+#include <errno.h>
+#include <fcntl.h>
 #include <stdlib.h>
 #include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
 #include <unistd.h>
-#include <ctype.h>
-#include <fcntl.h>
-#include <errno.h>
+#include <sys/stat.h>
+#include <sys/types.h>
 
-#include "camel-store-summary.h"
+#include <glib.h>
+#include <glib/gstdio.h>
+
+#include <libedataserver/e-memory.h>
+#include <libedataserver/md5-utils.h>
 
 #include "camel-file-utils.h"
-
-#include "libedataserver/md5-utils.h"
-#include "libedataserver/e-memory.h"
-
 #include "camel-private.h"
+#include "camel-store-summary.h"
 #include "camel-url.h"
 
 #define d(x)
@@ -349,7 +350,6 @@ camel_store_summary_path(CamelStoreSummary *s, const char *path)
 	return info;
 }
 
-
 /**
  * camel_store_summary_load:
  * @summary: a #CamelStoreSummary object
@@ -367,7 +367,7 @@ camel_store_summary_load(CamelStoreSummary *s)
 
 	g_assert(s->summary_path);
 
-	in = fopen(s->summary_path, "r");
+	in = g_fopen(s->summary_path, "rb");
 	if (in == NULL)
 		return -1;
 
@@ -433,12 +433,12 @@ camel_store_summary_save(CamelStoreSummary *s)
 		return 0;
 	}
 
-	fd = open(s->summary_path, O_RDWR|O_CREAT|O_TRUNC, 0600);
+	fd = g_open(s->summary_path, O_RDWR|O_CREAT|O_TRUNC|O_BINARY, 0600);
 	if (fd == -1) {
 		io(printf("**  open error: %s\n", strerror (errno)));
 		return -1;
 	}
-	out = fdopen(fd, "w");
+	out = fdopen(fd, "wb");
 	if ( out == NULL ) {
 		i = errno;
 		printf("**  fdopen error: %s\n", strerror (errno));
@@ -504,7 +504,7 @@ camel_store_summary_header_load(CamelStoreSummary *s)
 
 	g_assert(s->summary_path);
 
-	in = fopen(s->summary_path, "r");
+	in = g_fopen(s->summary_path, "rb");
 	if (in == NULL)
 		return -1;
 
