@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -991,6 +991,10 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 	tail = top;
 	for (i = 0; i < folders->len; i++) {
 		fi = folders->pdata[i];
+
+		if (fi->child)
+			fi->flags &= ~CAMEL_FOLDER_NOCHILDREN;
+
 		if (fi->parent || fi == top)
 			continue;
 		if (tail == NULL) {
