@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
  * Authors: Hans Petter Jansson <hpj@novell.com>
  */
@@ -38,14 +38,14 @@ G_BEGIN_DECLS
 #define E_IS_CONTACT_STORE_CLASS(klass) (GTK_CHECK_CLASS_TYPE ((klass), E_TYPE_CONTACT_STORE))
 #define E_CONTACT_STORE_GET_CLASS(obj)  (GTK_CHECK_GET_CLASS ((obj), E_TYPE_CONTACT_STORE, EContactStoreClass))
 
-typedef struct EContactStore       EContactStore;
-typedef struct EContactStoreClass  EContactStoreClass;
+typedef struct _EContactStore       EContactStore;
+typedef struct _EContactStoreClass  EContactStoreClass;
 
-struct EContactStoreClass {
+struct _EContactStoreClass {
 	GObjectClass parent_class;
 };
 
-struct EContactStore {
+struct _EContactStore {
 	GObject     parent;
 
 	/* Private */
@@ -72,6 +72,8 @@ void           e_contact_store_remove_book  (EContactStore *contact_store, EBook
 void           e_contact_store_set_query    (EContactStore *contact_store, EBookQuery *book_query);
 EBookQuery    *e_contact_store_peek_query   (EContactStore *contact_store);
 
+EBookView     *find_contact_source_by_book_return_view(EContactStore *contact_store, EBook *book);
+
 G_END_DECLS
 
 #endif  /* E_CONTACT_STORE_H */
