@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -66,7 +66,6 @@ fuzzy_level_to_name (int fuzzy_level, gboolean negated, const char *map[])
 }
 
 static const char *is_types[] = { NULL, NULL, NULL, NULL, "is", "is not" };
-static const char *include_types[] = { NULL, NULL, NULL, NULL, "include", "not include" };
 static const char *date_types[] = { "before", "before", "after", "after", NULL, NULL };
 static const char *size_types[] = { "less than", "less than", "greater than", "greater than", NULL, NULL };
 
