@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -45,13 +45,19 @@ add_folder_esource (ExchangeAccount *account,
 	GConfClient *client;
 	gboolean is_contacts_folder = TRUE, group_new = FALSE, source_new = FALSE;
 	const char *offline = NULL;
-	char *username, *authtype = NULL;
+	char *username, *useremail, *authtype = NULL;
 	int mode;
 	ESourceList *source_list = NULL;
-	gboolean offline_flag, update_selection = TRUE;
+	gboolean offline_flag, update_selection = TRUE, foriegn_folder;
 
 	client = gconf_client_get_default ();
 
+	/* decode the flag */
+	foriegn_folder = folder_type & FORIEGN_FOLDER_FLAG;
+
+	/* Unset the flag */
+	folder_type = folder_type & ~FORIEGN_FOLDER_FLAG;
+	
 	if (folder_type == EXCHANGE_CONTACTS_FOLDER) {
 		source_list = e_source_list_new_for_gconf ( client, 
 							CONF_KEY_CONTACTS);
@@ -75,6 +81,7 @@ add_folder_esource (ExchangeAccount *account,
 
 	exchange_account_is_offline_sync_set (account, &mode);
 	username = exchange_account_get_username (account);
+	useremail = exchange_account_get_email_id (account);
 	authtype = exchange_account_get_authtype (account);
 
         if ((source_group = e_source_list_peek_group_by_name (source_list, 
@@ -103,6 +110,13 @@ add_folder_esource (ExchangeAccount *account,
 			 */
 			e_source_set_property (source, "offline_sync", "1");
 		}
+		
+		if (foriegn_folder && (folder_type != EXCHANGE_CONTACTS_FOLDER)) {
+			e_source_set_property (source, "alarm", "never");
+			e_source_set_property (source, "foreign", "1");
+			e_source_set_property (source, "subscriber", useremail);
+		}
+
 		e_source_set_property (source, "username", username);
 		e_source_set_property (source, "auth-domain", "Exchange");
 		if (authtype)
@@ -140,6 +154,13 @@ add_folder_esource (ExchangeAccount *account,
 				e_source_set_property (source, "auth", "plain/password");
 			else
 				e_source_set_property (source, "auth", "1");
+
+			if (foriegn_folder && (folder_type != EXCHANGE_CONTACTS_FOLDER)) {
+				e_source_set_property (source, "alarm", "never");
+				e_source_set_property (source, "foreign", "1");
+				e_source_set_property (source, "subscriber", useremail);
+			}
+
 			e_source_group_add_source (source_group, source, -1);
 			source_new = TRUE;
 			e_source_list_sync (source_list, NULL);
