@@ -17,7 +17,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
  * USA
  */
 
@@ -97,6 +97,8 @@ int 	      e_gw_container_get_rights(EGwContainer *container, gchar *email);
 EGwContainerType e_gw_container_get_container_type (EGwContainer *container) ;
 void 	      e_gw_container_get_user_list(EGwContainer *container, GList **user_list);
 void	      e_gw_container_form_message (SoupSoapMessage *msg, gchar *id, GList *new_list, const char *sub, const char *mesg, int flag);
+gboolean e_gw_container_get_is_system_folder (EGwContainer *container);
+void e_gw_container_set_is_system_folder (EGwContainer *container, gboolean is_system_folder);
 
 G_END_DECLS
 
